@@ -1,6 +1,7 @@
 from re import match
 import os
 import base64
+from PIL import Image, ImageDraw
 
 def is_valid_tweet_url(url):
     result = match(
@@ -35,4 +36,19 @@ def image_base64(filename):
         with open(filename, "rb") as image_file:
             encoded_string = "data:image/png;base64," + base64.b64encode(image_file.read()).decode('ascii')
             return encoded_string
-    return ""
\ No newline at end of file
+    return ""
+
+
+
+def add_corners(im, rad):
+    circle = Image.new('L', (rad * 2, rad * 2), 0)
+    draw = ImageDraw.Draw(circle)
+    draw.ellipse((0, 0, rad * 2, rad * 2), fill=255)
+    alpha = Image.new('L', im.size, 255)
+    w, h = im.size
+    alpha.paste(circle.crop((0, 0, rad, rad)), (0, 0))
+    alpha.paste(circle.crop((0, rad, rad, rad * 2)), (0, h - rad))
+    alpha.paste(circle.crop((rad, 0, rad * 2, rad)), (w - rad, 0))
+    alpha.paste(circle.crop((rad, rad, rad * 2, rad * 2)), (w - rad, h - rad))
+    im.putalpha(alpha)
+    return im
\ No newline at end of file
